@@ -8,6 +8,7 @@
 #include "unionimage/unionimage.h"
 #include "imgviewlistview.h"
 #include "accessibility/ac-desktop-define.h"
+#include "service/imagedataservice.h"
 
 #include <QTimer>
 #include <QScroller>
@@ -33,6 +34,7 @@ DWIDGET_USE_NAMESPACE
 MyImageListWidget::MyImageListWidget(QWidget *parent)
     : QWidget(parent)
 {
+    qDebug() << "Initializing MyImageListWidget";
     QHBoxLayout *hb = new QHBoxLayout(this);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
@@ -40,98 +42,91 @@ MyImageListWidget::MyImageListWidget(QWidget *parent)
 
     m_listview = new LibImgViewListView(this);
     m_listview->setObjectName("ImgViewListView");
-    //    hb->addWidget(m_listview);
     m_listview->viewport()->installEventFilter(this);
     // 设置一个可以放置的高度
     m_listview->viewport()->setFixedHeight(90);
-    connect(m_listview, &LibImgViewListView::clicked, this, &MyImageListWidget::onClicked);
-    //    connect(m_listview->selectionModel(), &QItemSelectionModel::selectionChanged,
-    //            this, &MyImageListWidget::ONselectionChanged);
+    qDebug() << "ListView initialized with fixed height:" << m_listview->viewport()->height();
 
+    connect(m_listview, &LibImgViewListView::clicked, this, &MyImageListWidget::onClicked);
     connect(m_listview, &LibImgViewListView::openImg, this, &MyImageListWidget::openImg);
     connect(m_listview->horizontalScrollBar(), &QScrollBar::valueChanged, this, &MyImageListWidget::onScrollBarValueChanged);
+    
     initAnimation();
+    qDebug() << "Animation initialized";
 
     // 解决释放到程序外,不会动画的问题
-    connect(LibCommonService::instance(), &LibCommonService::sigRightMousePress, this, [=]
-            {
+    connect(LibCommonService::instance(), &LibCommonService::sigRightMousePress, this, [=] {
         qint64 currentTime = QDateTime::currentMSecsSinceEpoch();
-        if (currentTime - 100 > m_lastReleaseTime)
-        {
+        if (currentTime - 100 > m_lastReleaseTime) {
             m_lastReleaseTime = currentTime;
+            qDebug() << "Right mouse press detected, starting animation";
             animationStart(true, 0, 400);
-        } });
+        }
+    });
+    qDebug() << "MyImageListWidget initialization completed";
 }
-#include "service/imagedataservice.h"
+
 bool MyImageListWidget::eventFilter(QObject *obj, QEvent *e)
 {
-    if (e->type() == QEvent::Leave)
-    {
-        qDebug() << "QEvent::Leave" << obj;
+    if (e->type() == QEvent::Leave) {
+        qDebug() << "Mouse leave event on object:" << obj;
     }
-    if (e->type() == QEvent::MouseButtonPress)
-    {
-        if (!isEnabled())
-        {
+    
+    if (e->type() == QEvent::MouseButtonPress) {
+        if (!isEnabled()) {
+            qDebug() << "Widget disabled, ignoring mouse press";
             return true;
         }
 
         QMouseEvent *mouseEvent = dynamic_cast<QMouseEvent *>(e);
         m_pressPoint = mouseEvent->globalPos();
         m_movePoint = mouseEvent->globalPos();
-        qDebug() << m_movePoint;
         m_moveViewPoint = mouseEvent->globalPos();
+        qDebug() << "Mouse press at position:" << m_pressPoint;
 
         m_timer->start();
         m_movePoints.clear();
-
         m_preListGeometryLeft = m_listview->geometry().left();
-
         m_listview->update();
-        qDebug() << "------------getCount = " << LibImageDataService::instance()->getCount();
+        qDebug() << "Image count:" << LibImageDataService::instance()->getCount();
     }
-    if (e->type() == QEvent::MouseButtonRelease)
-    {
-        if (!isEnabled())
-        {
+
+    if (e->type() == QEvent::MouseButtonRelease) {
+        if (!isEnabled()) {
+            qDebug() << "Widget disabled, ignoring mouse release";
             return true;
         }
 
-        if (m_movePoints.size() > 0)
-        {
+        if (m_movePoints.size() > 0) {
             int endPos = m_movePoints.last().x() - m_movePoints.first().x();
+            qDebug() << "Mouse release, movement distance:" << endPos;
             // 过滤掉触屏点击时的move误操作
-            if (abs(m_movePoints.last().x() - m_movePoints.first().x()) > 15)
-            {
+            if (abs(m_movePoints.last().x() - m_movePoints.first().x()) > 15) {
+                qDebug() << "Starting inertia animation";
                 animationStart(false, endPos, 500);
-            }
-            else
-            {
+            } else {
+                qDebug() << "Starting reset animation";
                 animationStart(true, 0, 400);
             }
         }
-        // 松手，动画重置按钮应该所在的位置
-        //        animationStart(true, 0, 400);
     }
-    if (e->type() == QEvent::MouseMove || e->type() == QEvent::TouchUpdate)
-    {
-        if (!isEnabled())
-        {
+
+    if (e->type() == QEvent::MouseMove || e->type() == QEvent::TouchUpdate) {
+        if (!isEnabled()) {
+            qDebug() << "Widget disabled, ignoring mouse/touch move";
             return true;
         }
 
         QMouseEvent *mouseEvent = dynamic_cast<QMouseEvent *>(e);
-        if (!mouseEvent)
-        {
+        if (!mouseEvent) {
+            qWarning() << "Invalid mouse event";
             return false;
         }
+
         QPoint p = mouseEvent->globalPos();
-        if (m_movePoints.size() < 20)
-        {
+        if (m_movePoints.size() < 20) {
             m_movePoints.push_back(p);
-        }
-        else
-        {
+        } else {
             m_movePoints.pop_front();
             m_movePoints.push_back(p);
         }
@@ -141,67 +136,58 @@ bool MyImageListWidget::eventFilter(QObject *obj, QEvent *e)
         int offsetRowMove = rowWidth - ((rowWidth / RIGHT_LISTVIEW_MOVE_UPDATE) > 14 ? 12 : (rowWidth / RIGHT_LISTVIEW_MOVE_UPDATE - 3)) * RIGHT_LISTVIEW_MOVE_UPDATE;
         moveRangeX = moveRangeX > LEFT_LISTVIEW_MOVE_MAXLEN ? LEFT_LISTVIEW_MOVE_MAXLEN : moveRangeX;
         moveRangeX = moveRangeX < (LEFT_LISTVIEW_MOVE_MAXLEN - offsetRowMove) ? (LEFT_LISTVIEW_MOVE_MAXLEN - offsetRowMove) : moveRangeX;
+        
         m_listview->move(moveRangeX, m_listview->y());
         m_moveViewPoint = p;
+        qDebug() << "List view moved to position:" << moveRangeX;
 
         // 目的为了获取moveX的值,中心离当前位置的差值
         int moveX = 0;
         int middle = (this->geometry().right() - this->geometry().left()) / 2;
         int itemX = m_listview->x() + m_listview->getCurrentItemX() + 31;
-        if (rowWidth - m_listview->getCurrentItemX() < (this->geometry().width() / 2))
-        {
+        
+        if (rowWidth - m_listview->getCurrentItemX() < (this->geometry().width() / 2)) {
             moveX = this->geometry().width() - rowWidth - m_listview->x();
-        }
-        else if (m_listview->getCurrentItemX() < (this->geometry().width() / 2))
-        {
+        } else if (m_listview->getCurrentItemX() < (this->geometry().width() / 2)) {
             moveX = 0 - m_listview->pos().x();
-        }
-        else if (m_listview->geometry().width() <= this->width())
-        {
+        } else if (m_listview->geometry().width() <= this->width()) {
             moveX = 0;
-        }
-        else
-        {
+        } else {
             moveX = middle - itemX;
         }
+
         // moveX > 32或moveX <- 32则滑动两次(代表没有居中)
         // 如果这一次的移动并没有超过很大范围32-50,向右切换,并且m_movePoint位置记录为移动了32,这样的话可以保证每次切换流畅
-        if (m_listview->x() < 0 && m_movePoint.x() - p.x() >= 32 && m_movePoint.x() - p.x() <= 50)
-        {
+        if (m_listview->x() < 0 && m_movePoint.x() - p.x() >= 32 && m_movePoint.x() - p.x() <= 50) {
+            qDebug() << "Switching to next item (small movement)";
             m_listview->openNext();
             m_movePoint = QPoint(m_movePoint.x() - 32, m_movePoint.y());
-            if (moveX > 32)
-            {
+            if (moveX > 32) {
                 m_listview->openNext();
             }
-        }
-        // 如果这一次的移动并超过很大范围>50,向右切换,并且m_movePoint位置记录为移动了到了当前的位置,目的是在最前面滑动的时候做到始终显示在屏幕上,到开头才滑动
-        else if (m_listview->x() < 0 && m_movePoint.x() - p.x() > 32)
-        {
+        } else if (m_listview->x() < 0 && m_movePoint.x() - p.x() > 32) {
+            // 如果这一次的移动并超过很大范围>50,向右切换,并且m_movePoint位置记录为移动了到了当前的位置,
+            // 目的是在最前面滑动的时候做到始终显示在屏幕上,到开头才滑动
+            qDebug() << "Switching to next item (large movement)";
             m_listview->openNext();
             m_movePoint = QPoint(p.x(), m_movePoint.y());
-            if (moveX > 32)
-            {
+            if (moveX > 32) {
                 m_listview->openNext();
             }
-        }
-        // 同上,32-50之间则m_movePoint移动32
-        else if ((rowWidth - m_listview->getCurrentItemX() - moveX) > 0 && m_movePoint.x() - p.x() <= -32 && m_movePoint.x() - p.x() >= -50)
-        {
+        } else if ((rowWidth - m_listview->getCurrentItemX() - moveX) > 0 && m_movePoint.x() - p.x() <= -32 && m_movePoint.x() - p.x() >= -50) {
+            // 同上,32-50之间则m_movePoint移动32
+            qDebug() << "Switching to previous item (small movement)";
             m_listview->openPre();
             m_movePoint = QPoint(m_movePoint.x() + 32, m_movePoint.y());
-            if (moveX < -32)
-            {
+            if (moveX < -32) {
                 m_listview->openPre();
             }
-        }
-        //>50,超过边界则不移动,框框要在屏幕范围内
-        else if ((rowWidth - m_listview->getCurrentItemX() - moveX) > 0 && m_movePoint.x() - p.x() <= -32)
-        {
+        } else if ((rowWidth - m_listview->getCurrentItemX() - moveX) > 0 && m_movePoint.x() - p.x() <= -32) {
+            //>50,超过边界则不移动,框框要在屏幕范围内
+            qDebug() << "Switching to previous item (large movement)";
             m_listview->openPre();
             m_movePoint = QPoint(p.x(), m_movePoint.y());
-            if (moveX < -32)
-            {
+            if (moveX < -32) {
                 m_listview->openPre();
             }
         }
@@ -232,6 +218,7 @@ MyImageListWidget::~MyImageListWidget()
 
 void MyImageListWidget::setAllFile(QList<imageViewerSpace::ItemInfo> itemInfos, QString path)
 {
+    qDebug() << "Setting all files, count:" << itemInfos.size() << "current path:" << path;
     m_listview->setAllFile(itemInfos, path);
     this->setVisible(itemInfos.size() > 1);
     setSelectCenter();
@@ -283,15 +270,18 @@ void MyImageListWidget::clearListView()
 
 void MyImageListWidget::initAnimation()
 {
+    qDebug() << "Initializing animation components";
     m_timer = new QTimer(this);
     m_timer->setInterval(200);
     m_timer->setSingleShot(true);
-    if (m_listview)
-    {
+    
+    if (m_listview) {
         m_resetAnimation = new QPropertyAnimation(m_listview, "pos", nullptr); // 和上层m_obj的销毁绑在一起
     }
+    
     connect(m_resetAnimation, SIGNAL(finished()), this, SLOT(animationFinished()));
     connect(m_resetAnimation, SIGNAL(valueChanged(const QVariant)), this, SLOT(animationValueChanged(const QVariant)));
+    qDebug() << "Animation components initialized";
 }
 
 QString MyImageListWidget::getCurrentPath()
@@ -328,13 +318,12 @@ QStringList MyImageListWidget::getAllPath()
 void MyImageListWidget::animationFinished()
 {
     // 设置type标志用来判断是惯性动画还是复位动画
-    if (m_resetAnimation->property("type") == "500")
-    {
+    qDebug() << "Animation finished, type:" << m_resetAnimation->property("type").toString();
+    if (m_resetAnimation->property("type") == "500") {
         m_resetFinish = false;
         animationStart(true, 0, 400);
     }
-    if (m_resetAnimation->property("type") == "400")
-    {
+    if (m_resetAnimation->property("type") == "400") {
         m_resetFinish = true;
     }
 }
@@ -352,8 +341,10 @@ void MyImageListWidget::animationValueChanged(const QVariant value)
 
 void MyImageListWidget::animationStart(bool isReset, int endPos, int duration)
 {
-    if (m_resetAnimation->state() == QPropertyAnimation::State::Running)
-    {
+    qDebug() << "Starting animation, isReset:" << isReset << "endPos:" << endPos << "duration:" << duration;
+    
+    if (m_resetAnimation->state() == QPropertyAnimation::State::Running) {
+        qDebug() << "Stopping existing animation";
         m_resetAnimation->stop();
     }
 
@@ -362,34 +353,25 @@ void MyImageListWidget::animationStart(bool isReset, int endPos, int duration)
     int middle = (this->geometry().right() - this->geometry().left()) / 2;
     int itemX = m_listview->x() + m_listview->getCurrentItemX() + 31;
     int rowWidth = m_listview->getRowWidth();
-    if (rowWidth - m_listview->getCurrentItemX() < (this->geometry().width() / 2))
-    {
+    
+    if (rowWidth - m_listview->getCurrentItemX() < (this->geometry().width() / 2)) {
         moveX = this->geometry().width() - rowWidth - m_listview->x();
-    }
-    else if (m_listview->getCurrentItemX() < (this->geometry().width() / 2))
-    {
+    } else if (m_listview->getCurrentItemX() < (this->geometry().width() / 2)) {
         moveX = 0 - m_listview->pos().x();
-    }
-    else if (m_listview->geometry().width() <= this->width())
-    {
+    } else if (m_listview->geometry().width() <= this->width()) {
         moveX = 0;
-    }
-    else
-    {
+    } else {
         moveX = middle - itemX;
     }
 
-    if (!isReset)
-    {
+    if (!isReset) {
         moveX = endPos;
     }
+
     m_resetAnimation->setDuration(duration);
-    if (duration == 500)
-    {
+    if (duration == 500) {
         m_resetAnimation->setProperty("type", "500");
-    }
-    else
-    {
+    } else {
         m_resetAnimation->setProperty("type", "400");
     }
     m_resetAnimation->setEasingCurve(QEasingCurve::OutQuad);
@@ -399,8 +381,10 @@ void MyImageListWidget::animationStart(bool isReset, int endPos, int duration)
     int offsetRowMove = rowWidth - ((rowWidth / RIGHT_LISTVIEW_MOVE_UPDATE) >= 12 ? 9 : (rowWidth / RIGHT_LISTVIEW_MOVE_UPDATE - 3)) * RIGHT_LISTVIEW_MOVE_UPDATE;
     moveRangeX = moveRangeX > LEFT_LISTVIEW_MOVE_MAXLEN ? LEFT_LISTVIEW_MOVE_MAXLEN : moveRangeX;
     moveRangeX = moveRangeX < (LEFT_LISTVIEW_MOVE_MAXLEN - offsetRowMove) ? (LEFT_LISTVIEW_MOVE_MAXLEN - offsetRowMove) : moveRangeX;
+    
     m_resetAnimation->setEndValue(QPoint(moveRangeX, m_listview->pos().y()));
     m_resetAnimation->start();
+    qDebug() << "Animation started with end position:" << moveRangeX;
 }
 
 void MyImageListWidget::stopAnimation()
@@ -413,52 +397,43 @@ void MyImageListWidget::stopAnimation()
 
 void MyImageListWidget::thumbnailIsMoving()
 {
-    if (m_resetAnimation->state() == QPropertyAnimation::State::Running && m_resetAnimation->duration() == 400)
-    {
+    if (m_resetAnimation->state() == QPropertyAnimation::State::Running && m_resetAnimation->duration() == 400) {
         return;
     }
-    //    int endPos = m_movePoints.last().x() - m_movePoints.first().x();
+
     int offsetLimit = m_listview->geometry().left() - m_preListGeometryLeft;
-    if (abs(offsetLimit) <= 32)
-    {
+    if (abs(offsetLimit) <= 32) {
         return;
     }
-    qDebug() << offsetLimit;
+    qDebug() << "Thumbnail moving, offset:" << offsetLimit;
+
     // 目的为了获取moveX的值,中心离当前位置的差值
     int moveX = 0;
     int middle = (this->geometry().right() - this->geometry().left()) / 2;
     int itemX = m_listview->x() + m_listview->getCurrentItemX() + 31;
     int rowWidth = m_listview->getRowWidth();
-    if (rowWidth - m_listview->getCurrentItemX() < (this->geometry().width() / 2))
-    {
+    
+    if (rowWidth - m_listview->getCurrentItemX() < (this->geometry().width() / 2)) {
         moveX = this->geometry().width() - rowWidth - m_listview->x();
-    }
-    else if (m_listview->getCurrentItemX() < (this->geometry().width() / 2))
-    {
+    } else if (m_listview->getCurrentItemX() < (this->geometry().width() / 2)) {
         moveX = 0 - m_listview->pos().x();
-    }
-    else if (m_listview->geometry().width() <= this->width())
-    {
+    } else if (m_listview->geometry().width() <= this->width()) {
         moveX = 0;
-    }
-    else
-    {
+    } else {
         moveX = middle - itemX;
     }
+
     // 如果图片没居中,会切换两次
-    if (offsetLimit > 0)
-    {
+    if (offsetLimit > 0) {
+        qDebug() << "Moving to previous item";
         m_listview->openPre();
-        if (moveX < -32)
-        {
+        if (moveX < -32) {
             m_listview->openPre();
         }
-    }
-    else
-    {
+    } else {
+        qDebug() << "Moving to next item";
         m_listview->openNext();
-        if (moveX > 32)
-        {
+        if (moveX > 32) {
             m_listview->openNext();
         }
     }
@@ -516,9 +491,8 @@ void MyImageListWidget::openPre()
 
 void MyImageListWidget::onClicked(const QModelIndex &index)
 {
-    qDebug() << "---------";
-    if (m_timer->isActive())
-    {
+    qDebug() << "Item clicked at index:" << index.row();
+    if (m_timer->isActive()) {
         m_listview->onClicked(index);
     }
     animationStart(true, 0, 400);
